@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.012_01';
+our $VERSION = '0.013_01';
 
 our @CARP_NOT = qw{
     PPIx::QuoteLike
@@ -132,7 +132,8 @@ names, without the leading sigil. Nothing is captured.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -140,7 +141,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2020 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
