@@ -20,7 +20,7 @@ use PPIx::QuoteLike::Utils qw{
 
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.012_01';
+our $VERSION = '0.013_01';
 
 sub ppi {
     my ( $self ) = @_;
@@ -148,7 +148,8 @@ L<PPIx::QuoteLike::Token|PPIx::QuoteLike::Token>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -156,7 +157,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2020 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
